#include <iostream>
#include <string>
#include <vector>
using namespace std;

enum Command_type {Withdraw, Deposit, Transfer, Create, End};

class Account;
class Command;
class AccountManager;

// --------------------------
class Account {
	string ac_number;
	double balance;
public:
	Account(string n);
	Account(string n, double b);
	string &getNumber();
	double getBalance();
	void addVal(double val);
};

Account::Account(string n)
{
	ac_number = n;
}

Account::Account(string n, double b)
{
	ac_number = n;
	balance = b;
}

string &Account::getNumber()
{
	return ac_number;
}

double Account::getBalance()
{
	return balance;
}

void Account::addVal(double val)
{
	balance += val;
}

// --------------------------
class Command {
public:
	Command_type type;
	string number1, number2;
	double val;
//public:
	Command();
	void readCommand();
//	friend class AccountManager;
};

Command::Command()
{
	type = End;
	val = 0.0;
}

void Command::readCommand()
{
	string cmd_str;

	number1 = number2 = "";
	val = 0.0;

	cin >> cmd_str;
	switch(cmd_str.at(0)){
		case 'w':
			type = Withdraw;
			cin >> number1 >> val;
			break;
		case 't':
			type = Transfer;
			cin >> number1 >> number2 >> val;
			break;
		case 'c':
			type = Create;
			cin >> number1;
			break;
		case 'd':
			type = Deposit;
			cin >> number1 >> val;
			break;
		default:
			type = End;
			break;
	}
}

// --------------------------
class AccountManager {
public:
	vector<Account> account;

	AccountManager();
	int findAccount(string number);
	bool doCommand(Command cmd);
};

AccountManager::AccountManager()
{
	account.clear();
}

int AccountManager::findAccount(string number)
{
	unsigned int i, size;
	
	size = account.size();
	for(i=0; i<size; i++){
		if(number == account[i].getNumber()) return i;
	}
	return -1; // ucet neexistuje
}

bool AccountManager::doCommand(Command cmd)
{
	int acIndex1, acIndex2;
	double acBalance;

	cout.setf(ios::fixed);
	cout.precision(2);

	switch(cmd.type){
		case Withdraw:
			acIndex1 = findAccount(cmd.number1);
			if(acIndex1 == -1){ // neexistuje ucet pro vyber
				cout << "withdraw " << cmd.val << ": no such account" << endl;
				break;
			}
			acBalance = account[acIndex1].getBalance();
			if(acBalance < cmd.val){ // ucet existuje, ale je na nem malo penez
				cout << "withdraw " << cmd.val << ": insufficient funds" << endl;
				break;
			}
			// doslo se sem, vse je OK, provest vyber
			account[acIndex1].addVal(-cmd.val);
			cout << "withdraw " << cmd.val << ": ok" << endl;
			break;
		case Transfer:
			acIndex1 = findAccount(cmd.number1);
			acIndex2 = findAccount(cmd.number2);
			
			if(acIndex1 == -1 || acIndex2 == -1){ // jeden z uctu neexistuje
				cout << "transfer " << cmd.val << ": no such account" << endl;
				break;
			}
			if(acIndex1 == acIndex2){ // stejne ucty
				cout << "transfer " << cmd.val << ": same account" << endl;
				break;
			}

			acBalance = account[acIndex1].getBalance();

			if(acBalance < cmd.val){ // malo penez k prevodu
				cout << "transfer " << cmd.val << ": insufficient funds" << endl;
				break;
			}

			if(account[acIndex1].getNumber().at(5) != account[acIndex2].getNumber().at(5)){ // interbank
				cout << "transfer " << cmd.val << ": interbank" << endl;
				account[acIndex1].addVal(-cmd.val); // uberu z prvniho
				account[acIndex2].addVal(cmd.val); // pridam druhemu
				break;
			}

			cout << "transfer " << cmd.val << ": ok" << endl;
			account[acIndex1].addVal(-cmd.val); // uberu z prvniho
			account[acIndex2].addVal(cmd.val); // pridam druhemu
			
			break;
		case Create:
			acIndex1 = findAccount(cmd.number1);

			if(acIndex1 != -1){ // ucet jiz existuje
				cout << "create: already exists" << endl;
				break;
			}
			
			account.push_back(Account(cmd.number1)); // pridam ucet a vypisu OK
			cout << "create: ok" << endl;
			break;
		case Deposit:
			acIndex1 = findAccount(cmd.number1);

			if(acIndex1 == -1){ // ucet pro vlozeni neexistuje
				cout << "deposit " << cmd.val << ": no such account" << endl;
				break;
			}
			account[acIndex1].addVal(cmd.val); // pridam penize a vypisu OK
			cout << "deposit " << cmd.val << ": ok" << endl;
			break;
		default:
			return false;
			break;
	}
	return true;
}


// --------------------------
int main()
{
	unsigned int i, num_inputs;
	double read_balance;
	string read_acc_number, prazdny;
	bool get_next;
	AccountManager manager;
	Command cmd;

	cin >> num_inputs;
	while(num_inputs){
		manager.account.clear();
		for(i=0; i<num_inputs; i++){
			cin >> read_acc_number >> read_balance; // nacteni dat a vytvoreni pocatecnich uctu
			manager.account.push_back(Account(read_acc_number, read_balance));
		}

		get_next = true;
		while(get_next){
			cmd.readCommand();
			get_next = manager.doCommand(cmd);
		}
		cout << "end" << endl << endl;
	
		getline(cin, prazdny);
		cin >> num_inputs;
		//num_inputs = 0;
	}

	cout << "goodbye";
	return 0;
}
